@@ -16,8 +16,7 @@ from rich import print as rprint
 from uvicorn.main import LEVEL_CHOICES, LOOP_CHOICES
 
 import solara
-
-from .server import settings
+from solara.server import settings
 
 try:
     from solara_enterprise.ssg import ssg_crawl
@@ -63,7 +62,7 @@ LOGGING_CONFIG: dict = {
     },
     "loggers": {
         "solara": {"handlers": ["default"], "level": "ERROR"},
-        "react": {"handlers": ["default"], "level": "ERROR"},
+        "reacton": {"handlers": ["default"], "level": "ERROR"},
         # "react": {"handlers": ["rich"], "level": "DEBUG"},
         "uvicorn": {"handlers": ["default"], "level": "ERROR"},
         "uvicorn.error": {"level": "ERROR"},
@@ -259,7 +258,7 @@ def run(
         # We exclude the website, that will be handled by solara/server/reload.py
         reload_dirs = [str(solara_root), str(Path(solara.__file__).parent)]
         reload_excludes = reload_excludes if reload_excludes else []
-        reload_excludes = [str(solara_root / "website")]
+        reload_excludes = [str(solara_root / "website"), str(solara_root / "template")]
         del solara_root
         reload = True
         settings.main.mode = "development"
@@ -291,7 +290,7 @@ def run(
 
     if log_level is not None:
         LOGGING_CONFIG["loggers"]["solara"]["level"] = log_level.upper()
-        # LOGGING_CONFIG["loggers"]["react"]["level"] = log_level.upper()
+        # LOGGING_CONFIG["loggers"]["reacton"]["level"] = log_level.upper()
 
     log_level = log_level_uvicorn
     del log_level_uvicorn
@@ -438,7 +437,6 @@ def staticbuild():
     """Experimental static build"""
     # imports locals, otherwise .run() does not use the cli arguments
     import solara.server
-    import solara.server.patch
     import solara.server.server
 
     server_path = HERE / "server"
@@ -500,7 +498,6 @@ def staticbuild():
     for path in list(voila.glob("*.js")) + list(voila.glob("*.woff")):
         shutil.copy(path, target_dir_static_dist)
 
-    solara.server.patch.patch()
     index_html = solara.server.server.read_root("", render_kwargs={"for_pyodide": True}, use_nbextensions=True)
     assert index_html is not None
     (target_dir / "index.html").write_text(index_html)
@@ -553,7 +550,7 @@ def copytree(src: Path, dst: Path, copy_function=shutil.copy2, ignore: typing.Ca
     if not dst.exists():
         dst.mkdir(parents=True, exist_ok=True)
     for item in src.iterdir():
-        if ignore and ignore(item):
+        if ignore(item):
             continue
         if item.is_dir():
             copytree(item, dst / rename(item).name, ignore=ignore, copy_function=copy_function, rename=rename)
